@@ -1,5 +1,5 @@
 package Lab::Moose::Instrument::OI_IPS;
-$Lab::Moose::Instrument::OI_IPS::VERSION = '3.792';
+$Lab::Moose::Instrument::OI_IPS::VERSION = '3.800';
 #ABSTRACT: Oxford Instruments IPS Intelligent Power Supply
 
 use v5.20;
@@ -8,7 +8,7 @@ use Moose;
 use Moose::Util::TypeConstraints qw/enum/;
 use MooseX::Params::Validate;
 use Lab::Moose::Instrument qw/
-    validated_getter validated_setter setter_params /;
+    validated_getter validated_setter validated_no_param_setter setter_params /;
 use Lab::Moose::Instrument::Cache;
 use Lab::Moose::Countdown 'countdown';
 use Carp;
@@ -132,7 +132,7 @@ around query => sub {
         croak "IPS returned error '$result' on command '$cmd'";
     }
     elsif ( defined $cmd_char and ( $status ne $cmd_char ) ) {
-        croak "IPS returned unexpected answer. Expected '$cmd_char' prefix, 
+        croak "IPS returned unexpected answer. Expected '$cmd_char' prefix,
 received '$status' on command '$cmd'";
     }
     return substr( $result, 1 );
@@ -233,6 +233,60 @@ sub in_persistent_mode {
     }
 }
 
+sub set_persistent_mode {
+    my ( $self, %args ) = validated_setter( \@_,
+		value => {isa => 'Int'}
+	);
+
+    my $mode = delete %args{mode};
+
+    # return 0 if not $self->{device_settings}->{has_switchheater};
+
+    my $switch = $self->get_switch_heater();
+
+    #print "We are in mode $current_mode \n";
+
+    if ( $mode == 1 ) {
+
+        $self->hold();
+        $self->set_switch_heater(value => 0);
+
+        $self->to_zero();
+
+        #$current_mode = 1;
+
+    }
+    elsif ( $mode == 0 and $switch == 2 ) {
+
+        my $setpoint = $self->get_persistent_field();
+
+        $self->set_target_field(value => $setpoint);
+
+        $self->to_setpoint();
+
+        #print "Try to start switchheater...\n";
+        $self->set_switchheater(value => 1);
+
+        #print "Switchheater has status ".$self->get_switchheater();
+
+    }
+    elsif ( $mode == 0 and $switch == 0 ) {
+        print "Zero magnetic field. Switch on switchheater.\n";
+        $self->set_switchheater(value => 1);
+
+    }
+
+}
+
+sub get_persistent_field {
+    my ( $self, %args ) = validated_getter( \@_ );
+
+    # Are we really in persistent mode?
+
+    return $self->read_parameter(value => 18);
+
+}
+
 
 sub wait {
     my ( $self, %args ) = validated_getter( \@_ );
@@ -390,7 +444,7 @@ Lab::Moose::Instrument::OI_IPS - Oxford Instruments IPS Intelligent Power Supply
 
 =head1 VERSION
 
-version 3.792
+version 3.800
 
 =head1 SYNOPSIS
 
@@ -401,7 +455,7 @@ version 3.792
      type => 'OI_IPS',
      connection_type => 'LinuxGPIB',
      connection_options => {pad => 10},
-     
+
      # safety limits, should be fixed in a subclass of this driver
      max_fields => [7, 10],          # absolute maximum field of 10T
      max_field_rates => [0.1, 0.05], # 0.1 T/min maximum rate in range 0T..7T
@@ -526,7 +580,7 @@ This software is copyright (c) 2021 by the Lab::Measurement team; in detail:
 
   Copyright 2019       Simon Reinhardt
             2020       Andreas K. Huettel, Simon Reinhardt
-            2021       Simon Reinhardt
+            2021       Fabian Weinelt, Simon Reinhardt
 
 
 This is free software; you can redistribute it and/or modify it under
